package de.intevation.flys.client.shared.model;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class IntegerRangeData implements RangeData {

    public static final String TYPE = "intrange";


    protected String label;
    protected String description;

    protected int lower;
    protected int upper;

    protected Integer defLower;
    protected Integer defUpper;


    public IntegerRangeData() {
    }


    public IntegerRangeData(String label, String desc, int lower, int upper) {
        this(label, desc, lower, upper, null, null);
    }


    /**
     * @param label
     * @param desc
     * @param lower
     * @param upper
     * @param defLower
     * @param defUpper
     */
    public IntegerRangeData(
        String  label,
        String  desc,
        int     lower,
        int     upper,
        Integer defLower,
        Integer defUpper
    ) {
        this.label       = label;
        this.description = desc;
        this.lower       = lower;
        this.upper       = upper;
        this.defLower    = defLower;
        this.defUpper    = defUpper;
    }


    /**
     * Returns the label of the item.
     *
     * @return the label.
     */
    public String getLabel() {
        return label;
    }


    /**
     * Returns the description of the item.
     *
     * @return the description.
     */
    public String getDescription() {
        return description;
    }


    /**
     * Returns the type of the item.
     *
     * @return the type.
     */
    public String getType() {
        return "intrange";
    }


    /**
     * Returns a DataItem which value is a string that consists of the min and
     * max value separated by a ';'.
     *
     * @return the DataItem.
     */
    public DataItem[] getItems() {
        String theMin = String.valueOf(lower);
        String theMax = String.valueOf(upper);

        String label = theMin + " - " + theMax;
        String value = theMin + ";" + theMax;

        DataItem item  = new DefaultDataItem(label, label, value);

        return new DataItem[] { item };
    }


    /**
     * @return always null.
     */
    public DataItem getDefault() {
        return null;
    }


    public Object getLower() {
        return lower;
    }


    public Object getUpper() {
        return upper;
    }


    public Object getDefaultLower() {
        return defLower;
    }


    public Object getDefaultUpper() {
        return defUpper;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
